# drover
*drover: a command-line utility to deploy Python packages to Lambda functions*

## Supported Platforms
This utility has been tested on macOS Catalina 10.15.

## Usage
### Development Environment
Initialize a development environment by executing `nox`; the `drover` utility
will be installed in the `.nox/build-3-8` Python virtual environment binary
path.